@@ -10,19 +10,9 @@ import sqlite_utils
 from catt.api import CattDevice
 from rich.prompt import Confirm
 
+from xklb import utils
 from xklb.db import sqlite_con
-from xklb.utils import (
-    CAST_NOW_PLAYING,
-    DEFAULT_MPV_SOCKET,
-    DEFAULT_PLAY_QUEUE,
-    SC,
-    cmd,
-    filter_None,
-    flatten,
-    get_ip_of_chromecast,
-    log,
-    pkill,
-)
+from xklb.utils import SC, cmd, log
 from xklb.utils_player import (
     delete_media,
     get_ordinal_media,
@@ -42,7 +32,220 @@ idle_mpv = lambda args: ["mpv", "--idle", f"--input-ipc-server={args.mpv_socket}
 
 
 def parse_args(action, default_db, default_chromecast=""):
-    parser = argparse.ArgumentParser(formatter_class=argparse.ArgumentDefaultsHelpFormatter)
+    parser = argparse.ArgumentParser(
+        prog="lb " + action,
+        usage=f"""lb {action} [database] [optional args]
+
+    If not specified, {action} will try to read {default_db} in the working directory:
+
+        lb {action}
+
+    Override the default player (mpv):
+
+        lb does a lot of things to try to automatically use your preferred media player
+        but if it doesn't guess right you can make it explicit:
+
+        lb {action} --player "vlc --vlc-opts"
+
+    Cast to chromecast groups:
+
+        lb {action} --cast --cast-to "Office pair"
+        lb {action} -ct "Office pair"  # equivalent
+
+        If you don't know the exact name of your chromecast group run `catt scan`
+
+    Print instead of play:
+
+        Generally speaking, you should always be able to add `-p` to check what the play queue will look like before playing--even while using many other option simultaneously.
+        The only exceptions that I can think of are `-OO` and `-OOO`. In those cases the results might lie.
+
+        lb {action} --print --limit 10  # print the next 10 files
+        lb {action} -p -L 10  # print the next 10 files
+        lb {action} -p  # be cautious about running -p on an unfiltered set because this will print _all_ the media
+
+        Printing modes
+
+        lb {action} -p    # print in a table
+        lb {action} -p p  # equivalent
+        lb {action} -p a  # print an aggregate report
+        lb {action} -p f  # print fields -- useful for piping paths to utilities like xargs or GNU Parallel
+
+        Check if you've downloaded something before
+
+        lb {action} -u duration -p -s 'title'
+
+        Print an aggregate report of deleted media
+
+        lb {action} -w is_deleted=1 -p a
+        ╒═══════════╤══════════════╤═════════╤═════════╕
+        │ path      │ duration     │ size    │   count │
+        ╞═══════════╪══════════════╪═════════╪═════════╡
+        │ Aggregate │ 14 days, 23  │ 50.6 GB │   29058 │
+        │           │ hours and 42 │         │         │
+        │           │ minutes      │         │         │
+        ╘═══════════╧══════════════╧═════════╧═════════╛
+        Total duration: 14 days, 23 hours and 42 minutes
+
+
+        Print an aggregate report of media that has no duration information (likely corrupt media)
+
+        lb {action} -w 'duration is null' -p a
+
+        Print a list of videos which have below 1280px resolution
+
+        lb wt -w 'width<1280' -p f
+
+        View how much time you have listened to music
+
+        lb lt -w play_count'>'0 -p a
+
+        See how much video you have
+
+        lb wt video.db -p a
+        ╒═══════════╤═════════╤═════════╤═════════╕
+        │ path      │   hours │ size    │   count │
+        ╞═══════════╪═════════╪═════════╪═════════╡
+        │ Aggregate │  145769 │ 37.6 TB │  439939 │
+        ╘═══════════╧═════════╧═════════╧═════════╛
+        Total duration: 16 years, 7 months, 19 days, 17 hours and 25 minutes
+
+
+        View all the columns
+
+        lb {action} -p -L 1 --cols '*'
+
+        Open ipython with all of your media
+
+        lb {action} -vv -p --cols '*'
+        ipdb> len(db_resp)
+        462219
+
+    Set the play queue size:
+
+        By default the play queue is 120. Long enough that you probably haven't noticed but short enough that the program is snappy.
+
+        If you want everything in your play queue you can use the aid of infinity.
+
+        Pick your poison (these all do effectively the same thing):
+        lb {action} -L inf
+        lb {action} -l inf
+        lb {action} --queue inf
+        lb {action} -L 99999999999999999999999
+
+        You might also want to restrict the play queue when you only want 1000 random files for example:
+
+        lb {action} -u random -L 1000
+
+    Offset the play queue:
+
+        You can also offset the queue. For example if you want to skip one or ten media:
+
+        lb {action} -S 10  # offset ten from the top of an ordered query
+
+    Repeat
+
+        lt                  # listen to 120 random songs (DEFAULT_PLAY_QUEUE)
+        lt --limit 5        # listen to FIVE songs
+        lt -l inf -u random # listen to random songs indefinitely
+        lt -s infinite      # listen to songs from the band infinite
+
+    Constrain media by search:
+
+        Audio files have many tags to readily search through so metadata like artist, album, and even mood are included in search.
+        Video files have less consistent metadata and so only paths are included in search.
+
+        lb {action} --include happy  # only matches will be included
+        lb {action} -s happy         # equivalent
+
+        lb {action} --exclude sad   # matches will be excluded
+        lb {action} -E sad          # equivalent
+
+        Double spaces are parsed as one space
+
+        -s '  ost'        # will match OST and not ghost
+        -s toy story      # will match '/folder/toy/something/story.mp3'
+        -s 'toy  story'    # will match more strictly '/folder/toy story.mp3'
+
+    Constrain media by arbitrary SQL expressions:
+
+        lb {action} --where audio_count = 2  # media which have two audio tracks
+        lb {action} -w "language = 'eng'"    # media which have an English language tag (this could be audio or subtitle)
+        lb {action} -w subtitle_count=0      # media that doesn't have subtitles
+
+    Constrain media to duration (in minutes):
+
+        lb {action} --duration 20
+
+        lb {action} -d 6  # 6 mins ±10 percent (ie. between 5 and 7 mins)
+        lb {action} -d-6  # less than 6 mins
+        lb {action} -d+6  # more than 6 mins
+
+        Can be specified multiple times:
+
+        lb {action} -d+5 -d-7  # should be similar to -d 6
+
+        If you want exact time use `where`
+
+        lb {action} --where 'duration=6*60'
+
+    Constrain media to file size (in megabytes):
+
+        lb {action} --size 20
+
+        lb {action} -z 6  # 6 MB ±10 percent (ie. between 5 and 7 MB)
+        lb {action} -z-6  # less than 6 MB
+        lb {action} -z+6  # more than 6 MB
+
+    Constrain media by throughput:
+
+        Bitrate information is not explicitly saved but you can use file size and duration as a proxy:
+
+        wt -w 'size/duration<50000'
+
+    Constrain media to portrait orientation video:
+
+        lb {action} --portrait
+        lb {action} -w 'width<height' # equivalent
+
+    Specify media play order:
+
+        lb {action} --sort duration   # play shortest media first
+        lb {action} -u duration desc  # play longest media first
+
+        You can use multiple SQL ORDER BY expressions
+
+        lb {action} -u subtitle_count > 0 desc # play media that has at least one subtitle first
+
+    Play media in order (similarly named episodes):
+
+        lb {action} --play-in-order
+
+        There are multiple strictness levels of --play-in-order.
+        If things aren't playing in order try adding more `O`s:
+
+        lb {action} -O    # normal
+        lb {action} -OO   # slower, more complex algorithm
+        lb {action} -OOO  # strict
+
+    Post-actions -- choose what to do after playing:
+
+        lb {action} --post-action delete  # delete file after playing
+        lb {action} -k ask  # ask after each whether to keep or delete
+        lb {action} -k askkeep  # ask after each whether to move to a keep folder or delete
+
+        The default location of the keep folder is ./keep/ relative to each individual media file
+        You can change this by explicitly setting an absolute `keep-dir` path:
+
+        lb {action} -k askkeep --keep-dir /home/my/music/keep/
+
+    Experimental options:
+
+        Duration to play (in seconds) while changing the channel
+
+        lb {action} --interdimensional-cable 40
+        lb {action} -4dtv 40
+""",
+    )
 
     parser.add_argument(
         "database",
@@ -52,156 +255,49 @@ def parse_args(action, default_db, default_chromecast=""):
     )
 
     # TODO: maybe try https://dba.stackexchange.com/questions/43415/algorithm-for-finding-the-longest-prefix
-    parser.add_argument(
-        "--play-in-order",
-        "-O",
-        action="count",
-        default=0,
-        help="Try to get things to play in order -- similarly named episodes",
-    )
-    parser.add_argument(
-        "--duration",
-        "-d",
-        action="append",
-        help="""Media duration in minutes:
--d 6 means 6 mins ±10 percent -- between 5 and 7 mins
--d-6 means less than 6 mins
--d+6 means more than 6 mins
+    parser.add_argument("--play-in-order", "-O", action="count", default=0, help=argparse.SUPPRESS)
+    parser.add_argument("--duration", "-d", action="append", help=argparse.SUPPRESS)
+    parser.add_argument("--sort", "-u", nargs="+", help=argparse.SUPPRESS)
+    parser.add_argument("--where", "-w", nargs="+", action="extend", default=[], help=argparse.SUPPRESS)
+    parser.add_argument("--include", "-s", "--search", nargs="+", action="extend", default=[], help=argparse.SUPPRESS)
+    parser.add_argument("--exclude", "-E", "-e", nargs="+", action="extend", default=[], help=argparse.SUPPRESS)
 
--d+5 -d-7 should be similar to -d 6
+    parser.add_argument("--chromecast-device", "--cast-to", "-t", default=default_chromecast, help=argparse.SUPPRESS)
+    parser.add_argument("--chromecast", "--cast", "-c", action="store_true", help=argparse.SUPPRESS)
+    parser.add_argument("--with-local", "-wl", action="store_true", help=argparse.SUPPRESS)
+    parser.add_argument("--interdimensional-cable", "-4dtv", type=int, help=argparse.SUPPRESS)
+    parser.add_argument("--portrait", "-portrait", action="store_true", help=argparse.SUPPRESS)
 
-if you want exact times you can use --where duration=6*60
-""",
-    )
-    parser.add_argument(
-        "--sort",
-        "-u",
-        nargs="+",
-        help="""Sort media with SQL expressions
--u duration means shortest media first
--u duration desc means longest media first
+    parser.add_argument("--prefix", default="", help=argparse.SUPPRESS)
 
-You can use any sqlite ORDER BY expressions, for example:
--u subtitle_count > 0
-means play everything that has a subtitle first
-""",
-    )
-    parser.add_argument(
-        "--where",
-        "-w",
-        nargs="+",
-        action="extend",
-        default=[],
-        help="""Constrain media with SQL expressions
-You can use any sqlite WHERE expressions, for example:
--w attachment_count > 0  means only media with attachments
--w language = 'eng'  means only media which has some English language tag -- this could be audio or subtitle""",
-    )
-    parser.add_argument(
-        "--include",
-        "-s",
-        "--search",
-        nargs="+",
-        action="extend",
-        default=[],
-        help="""Constrain media with via search
--s toy story will match '/folder/toy/something/story.mp3'
--s 'toy  story' will match more strictly '/folder/toy story.mp3'
-Double spaces means one space
-""",
-    )
-    parser.add_argument("--exclude", "-E", "-e", nargs="+", action="extend", default=[])
+    parser.add_argument("--size", "-z", action="append", help=argparse.SUPPRESS)
+
+    parser.add_argument("--print", "-p", default=False, const="p", nargs="?", help=argparse.SUPPRESS)
+    parser.add_argument("--moved", nargs=2, help=argparse.SUPPRESS)
+
+    parser.add_argument("--cols", "-cols", "-col", nargs="*", help=argparse.SUPPRESS)
+    parser.add_argument("--limit", "-L", "-l", "-queue", "--queue", help=argparse.SUPPRESS)
+    parser.add_argument("--skip", "-S", help=argparse.SUPPRESS)
+
+    parser.add_argument("--start", "-vs", help=argparse.SUPPRESS)
+    parser.add_argument("--end", "-ve", help=argparse.SUPPRESS)
+    parser.add_argument("--player", "-player", help=argparse.SUPPRESS)
+    parser.add_argument("--mpv-socket", default=utils.DEFAULT_MPV_SOCKET, help=argparse.SUPPRESS)
 
     parser.add_argument(
-        "--chromecast-device",
-        "-cast-to",
-        default=default_chromecast,
-        help="The name of your chromecast device or group. Use exact uppercase/lowercase",
+        "--player-args-when-sub", "-player-sub", nargs="*", default=["--speed=1"], help=argparse.SUPPRESS
     )
     parser.add_argument(
-        "--chromecast", "-cast", action="store_true", help="Turn chromecast on. Use like this: lt -cast or tl -cast"
+        "--player-args-when-no-sub", "-player-no-sub", nargs="*", default=["--speed=1.7"], help=argparse.SUPPRESS
     )
-    parser.add_argument(
-        "--with-local",
-        "-wl",
-        action="store_true",
-        help="Play with local speakers and chromecast at the same time [experimental]",
-    )
-    parser.add_argument(
-        "--interdimensional-cable",
-        "-4dtv",
-        type=int,
-        help="Duration to play (in seconds) while changing the channel [experimental]",
-    )
-    parser.add_argument("--portrait", "-portrait", action="store_true")
+    parser.add_argument("--transcode", action="store_true", help=argparse.SUPPRESS)
 
-    parser.add_argument("--prefix", default="", help="change root prefix; useful for sshfs")
+    parser.add_argument("--post-action", "--action", "-k", default="keep", help=argparse.SUPPRESS)
+    parser.add_argument("--keep-dir", "--keepdir", default="keep", help=argparse.SUPPRESS)
+    parser.add_argument("--shallow-organize", default="/mnt/d/", help=argparse.SUPPRESS)
 
-    parser.add_argument("--size", "-z", action="append", help="Constrain media with via size in Megabytes")
-
-    parser.add_argument(
-        "--print",
-        "-p",
-        default=False,
-        const="p",
-        nargs="?",
-        help="""Print instead of play
--p   means print in a table
--p a means print an aggregate report
--p f means print only filenames -- useful for piping to other utilities like xargs or GNU Parallel""",
-    )
-    parser.add_argument(
-        "--moved",
-        nargs=2,
-        help="""For use with `-p f` to specify files moved with rsync or a similar tool. For example:
-rsync -a --info=progress2 --no-inc-recursive --remove-source-files --files-from=<(
-    lt ~/lb/audio.db -w 'play_count = 0' -u random -L 1200 -p f \
-    --moved /mnt/d/ /mnt/d/80_Now_Listening/
-) /mnt/d/ /mnt/d/80_Now_Listening/
-
-Notice how `--moved` mirrors the src/dest prefix syntax in rsync?""",
-    )
-
-    parser.add_argument("--cols", "-cols", "-col", nargs="*", help="Include a non-standard column when printing")
-    parser.add_argument("--limit", "-L", "-l", "-queue", "--queue", help="Set play queue size")
-    parser.add_argument("--skip", "-S", help="Offset from the top of an ordered query; wt -S10 to skip ten videos")
-
-    parser.add_argument(
-        "--start", "-vs", help='Set the time to skip from the start of the media or use the magic word "wadsworth"'
-    )
-    parser.add_argument(
-        "--end", "-ve", help='Set the time to skip from the end of the media or use the magic word "dawsworth"'
-    )
-    parser.add_argument("--player", "-player", help='Override the default player; wt --player "vlc --vlc-opts"')
-    parser.add_argument("--mpv-socket", default=DEFAULT_MPV_SOCKET)
-
-    parser.add_argument(
-        "--player-args-when-sub",
-        "-player-sub",
-        nargs="*",
-        default=["--speed=1"],
-        help="Only give args for videos with subtitles",
-    )
-    parser.add_argument(
-        "--player-args-when-no-sub",
-        "-player-no-sub",
-        nargs="*",
-        default=["--speed=1.7"],
-        help="Only give args for videos without subtitles",
-    )
-    parser.add_argument("--transcode", action="store_true")
-
-    parser.add_argument("--post-action", "--action", "-k", default="keep", help="Choose what to do after playing")
-    parser.add_argument(
-        "--keep-dir",
-        "--keepdir",
-        default="keep",
-        help="Used with post-action askkeep. Files will move here after playing",
-    )
-    parser.add_argument("--shallow-organize", default="/mnt/d/")
-
-    parser.add_argument("--db", "-db")
-    parser.add_argument("--ignore-errors", "--ignoreerrors", action="store_true")
+    parser.add_argument("--db", "-db", help=argparse.SUPPRESS)
+    parser.add_argument("--ignore-errors", "--ignoreerrors", action="store_true", help=argparse.SUPPRESS)
     parser.add_argument("--verbose", "-v", action="count", default=0)
     args = parser.parse_args()
     args.action = action
@@ -210,7 +306,7 @@ Notice how `--moved` mirrors the src/dest prefix syntax in rsync?""",
         args.database = args.db
 
     if not args.limit and all([not args.print, args.action in [SC.listen, SC.watch, SC.tubelisten, SC.tubewatch]]):
-        args.limit = DEFAULT_PLAY_QUEUE
+        args.limit = utils.DEFAULT_PLAY_QUEUE
     elif args.limit in ["inf", "all"]:
         args.limit = None
 
@@ -221,7 +317,7 @@ Notice how `--moved` mirrors the src/dest prefix syntax in rsync?""",
         args.sort = override_sort(args.sort)
 
     if args.cols:
-        args.cols = list(flatten([s.split(",") for s in args.cols]))
+        args.cols = list(utils.flatten([s.split(",") for s in args.cols]))
 
     if args.duration:
         SEC_TO_M = 60
@@ -265,12 +361,12 @@ Notice how `--moved` mirrors the src/dest prefix syntax in rsync?""",
 
     if args.chromecast:
         args.cc = CattDevice(args.chromecast_device, lazy=True)
-        args.cc_ip = get_ip_of_chromecast(args.chromecast_device)
+        args.cc_ip = utils.get_ip_of_chromecast(args.chromecast_device)
 
     if args.player:
         args.player = shlex.split(args.player)
 
-    log.info(filter_None(args.__dict__))
+    log.info(utils.filter_None(args.__dict__))
 
     args.sock = None
     return args
@@ -498,9 +594,9 @@ def construct_fs_query(args):
     {args.sql_filter}
     {'and audio_count > 0' if args.action == SC.listen else ''}
     {'and video_count > 0' if args.action == SC.watch else ''}
-    {f'and path not like "%/{args.keep_dir}%"' if args.post_action == 'askkeep' else ''}
+    {f'and path not like "%{args.keep_dir}%"' if args.post_action == 'askkeep' else ''}
     {'and width < height' if args.portrait else ''}
-    {'and is_deleted=0' if args.action in [SC.listen, SC.watch] else ''}
+    {'and is_deleted=0' if args.action in [SC.listen, SC.watch] and 'is_deleted' not in args.sql_filter else ''}
     ORDER BY 1=1
         {',' + args.sort if args.sort else ''}
         {', path' if args.print or args.include or args.play_in_order > 0 else ''}
@@ -530,10 +626,10 @@ def process_actions(args, construct_query=construct_fs_query):
         play(args, media)
     finally:
         if args.interdimensional_cable:
-            pkill(idle_mpv(args), strict=False)
+            utils.pkill(idle_mpv(args), strict=False)
         Path(args.mpv_socket).unlink(missing_ok=True)
         if args.chromecast:
-            Path(CAST_NOW_PLAYING).unlink(missing_ok=True)
+            Path(utils.CAST_NOW_PLAYING).unlink(missing_ok=True)
 
 
 def watch():
